diff src/blist.h @ 10662:54ac161a876e

[gaim-migrate @ 12199] Plugins can now add submenus to the right-click menu of a blist node by passing a GList of actions to gaim_blist_node_action_new. I'm thinking about making GaimBlistNodeActions more like plugin prefs so that plugins can create radio and check menu items as well. We'll see if I can do that and not make it ugly/suck. committer: Tailor Script <tailor@pidgin.im>
author Etan Reisner <pidgin@unreliablesource.net>
date Mon, 07 Mar 2005 02:19:09 +0000
parents 54f7939df8e3
children a4ae4fb7f939
line wrap: on
line diff
--- a/src/blist.h	Mon Mar 07 01:25:05 2005 +0000
+++ b/src/blist.h	Mon Mar 07 02:19:09 2005 +0000
@@ -199,6 +199,7 @@
 	char *label;
 	void (*callback)(GaimBlistNode *, gpointer);
 	gpointer data;
+	GList *children;
 };
 
 
@@ -866,13 +867,17 @@
 
 /**
  * Creates a new GaimBlistNodeAction.
  * @param label		The text label to display for this action.
  * @param callback	The function to be called when the action is used on
  *			a selected GaimBlistNode.
  * @param data		Additional data, to be passed to the callback
  */
-GaimBlistNodeAction  *gaim_blist_node_action_new(char *label,
-		void (*callback)(GaimBlistNode *, gpointer), gpointer data);
+GaimBlistNodeAction *gaim_blist_node_action_new(char *label,
+		void (*callback)(GaimBlistNode *, gpointer), gpointer data,
+		GList *children);
 
 
 /**************************************************************************/
@@ -866,13 +867,17 @@
 /**
  * Creates a new GaimBlistNodeAction.
- * @param label		The text label to display for this action.
- * @param callback	The function to be called when the action is used on
- *			a selected GaimBlistNode.
- * @param data		Additional data, to be passed to the callback
+ * @param label         The text label to display for this action.
+ * @param callback      The function to be called when the action is used on
+ *                      a selected GaimBlistNode.
+ * @param data          Additional data, to be passed to the callback
+ * @param children      A GList of GaimBlistNodeActions to be added as a
+ *                      submenu of the action.
+ * @return              The GaimBlistNodeAction.
  */